@@ -376,6 +376,7 @@ gnome_vfs_job_destroy_notify_result (GnomeVFSNotifyResult *notify_result)
 	case GNOME_VFS_OP_OPEN:
 	case GNOME_VFS_OP_OPEN_AS_CHANNEL:
 	case GNOME_VFS_OP_READ:
+	case GNOME_VFS_OP_XFER:
 		g_free (notify_result);
 		break;
 		
@@ -708,7 +709,7 @@ gnome_vfs_op_destroy (GnomeVFSOp *op)
 	
 	g_assert (gnome_vfs_context_get_cancellation (op->context) != NULL);
 	
-	gnome_vfs_context_unref (op->context);
+	gnome_vfs_context_free (op->context);
 	gnome_vfs_module_callback_free_stack_info (op->stack_info);
 	
 	g_free (op);
