@@ -593,6 +593,28 @@ read_link (const gchar *full_name)
 	}
 }
 
+static void
+get_access_info (GnomeVFSFileInfo *file_info,
+              const gchar *full_name)
+{
+     /* FIXME: should check errno after calling access because we don't
+      * want to set valid_fields if something bad happened during one
+      * of the access calls
+      */
+     if (access (full_name, R_OK) == 0) {
+             file_info->permissions |= GNOME_VFS_PERM_ACCESS_READABLE;
+     }
+
+     if (access (full_name, W_OK) == 0) {
+             file_info->permissions |= GNOME_VFS_PERM_ACCESS_WRITABLE;
+     }
+
+     if (access (full_name, X_OK) == 0) {
+             file_info->permissions |= GNOME_VFS_PERM_ACCESS_EXECUTABLE;
+     }
+     file_info->valid_fields |= GNOME_VFS_FILE_INFO_FIELDS_ACCESS;
+}
+
 static GnomeVFSResult
 get_stat_info (GnomeVFSFileInfo *file_info,
 	       const gchar *full_name,
@@ -823,6 +845,10 @@ do_get_file_info (GnomeVFSMethod *method,
 		return result;
 	}
 
+	if (options & GNOME_VFS_FILE_INFO_GET_ACCESS_RIGHTS) {
+		get_access_info (file_info, full_name);
+	}
+
 	if (options & GNOME_VFS_FILE_INFO_GET_MIME_TYPE) {
 		get_mime_type (file_info, full_name, options, &statbuf);
 	}
